Class: CapitalOneStatement::Transaction
- Inherits:
-
Struct
- Object
- Struct
- CapitalOneStatement::Transaction
- Defined in:
- lib/parse_capitalone_pdf_statement.rb
Overview
CapitalOneStatement::Transaction represents a single credit transaction
Instance Attribute Summary collapse
-
#amount ⇒ Float
The dollar amount parsed into a Float, negative for payments.
-
#amount_str ⇒ String
The dollar amount string of the transaction.
-
#date ⇒ Date
The date of the transaction.
-
#description ⇒ String
The description of the transaction.
-
#id ⇒ Fixnum
Transaction id.
Instance Method Summary collapse
-
#to_json(*args) ⇒ String
JSON representation of Transaction.
Instance Attribute Details
#amount ⇒ Float
Returns the dollar amount parsed into a Float, negative for payments.
234 235 236 |
# File 'lib/parse_capitalone_pdf_statement.rb', line 234 def amount @amount end |
#amount_str ⇒ String
Returns the dollar amount string of the transaction.
234 235 236 |
# File 'lib/parse_capitalone_pdf_statement.rb', line 234 def amount_str @amount_str end |
#date ⇒ Date
Returns the date of the transaction.
234 235 236 |
# File 'lib/parse_capitalone_pdf_statement.rb', line 234 def date @date end |
#description ⇒ String
Returns the description of the transaction.
234 235 236 |
# File 'lib/parse_capitalone_pdf_statement.rb', line 234 def description @description end |
#id ⇒ Fixnum
Returns transaction id.
234 235 236 |
# File 'lib/parse_capitalone_pdf_statement.rb', line 234 def id @id end |
Instance Method Details
#to_json(*args) ⇒ String
Returns JSON representation of Transaction.
257 258 259 |
# File 'lib/parse_capitalone_pdf_statement.rb', line 257 def to_json(*args) to_h.to_json(*args) end |